@@ -4,5 +4,5 @@ import os
 from .io import load_image_data_file
 
 IMAGE_TOPOLOGY = json.load(
-    open(os.path.join(os.path.dirname(__file__), "metadata", "region-topolgy.json"))
+    open(os.path.join(os.path.dirname(__file__), "metadata", "region-topology.json"))
 )
