@@ -1,8 +1,5 @@
 from .activity import change_exchanges_by_constant_factor
-from .cleaning import (
-    delete_zero_amount_exchanges,
-    empty_market_dataset,
-)
+from .cleaning import delete_zero_amount_exchanges, empty_market_dataset
 from .geo import (
     copy_to_new_location,
     default_global_location,
